@@ -38,6 +38,7 @@ class TestIsUrl(unittest.TestCase):
 			'https://api.twitter.com/1.1/search/%20/tweets.json',
 			'http://foo.com/blahblah_(wikipedia)',
 			'https://test-domain.com/',
+			'ha.com'
         ]
 		self.valid_check(valid_items)
 		print('OK - test_valid_url')
@@ -72,6 +73,7 @@ class TestIsUrl(unittest.TestCase):
 			'hello%world.io',
 			'hello:world.io',
 			'hello~world.io',
+			'h.com'
         ]
 		self.invalid_check(invalid_items)
 		print('OK - test_invalid_url')
